==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/azurestackhci/kotlin/inputs/InfrastructureNetworkArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.azurestackhci.kotlin.inputs

import com.pulumi.azurenative.azurestackhci.inputs.InfrastructureNetworkArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * The InfrastructureNetwork of a AzureStackHCI Cluster.
 * @property dnsServers IPv4 address of the DNS servers in your environment.
 * @property gateway Default gateway that should be used for the provided IP address space.
 * @property ipPools Range of IP addresses from which addresses are allocated for nodes within a subnet.
 * @property subnetMask Subnet mask that matches the provided IP address space.
 * @property useDhcp Allows customers to use DHCP for Hosts and Cluster IPs. If not declared, the deployment will default to static IPs. When true, GW and DNS servers are not required
 */
public data class InfrastructureNetworkArgs(
    public val dnsServers: Output<List<String>>? = null,
    public val gateway: Output<String>? = null,
    public val ipPools: Output<List<IpPoolsArgs>>? = null,
    public val subnetMask: Output<String>? = null,
    public val useDhcp: Output<Boolean>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.azurestackhci.inputs.InfrastructureNetworkArgs> {
    override fun toJava(): com.pulumi.azurenative.azurestackhci.inputs.InfrastructureNetworkArgs =
        com.pulumi.azurenative.azurestackhci.inputs.InfrastructureNetworkArgs.builder()
            .dnsServers(dnsServers?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .gateway(gateway?.applyValue({ args0 -> args0 }))
            .ipPools(
                ipPools?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .subnetMask(subnetMask?.applyValue({ args0 -> args0 }))
            .useDhcp(useDhcp?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [InfrastructureNetworkArgs].
 */
@PulumiTagMarker
public class InfrastructureNetworkArgsBuilder internal constructor() {
    private var dnsServers: Output<List<String>>? = null

    private var gateway: Output<String>? = null

    private var ipPools: Output<List<IpPoolsArgs>>? = null

    private var subnetMask: Output<String>? = null

    private var useDhcp: Output<Boolean>? = null

    /**
     * @param value IPv4 address of the DNS servers in your environment.
     */
    @JvmName("psduyndtycgpugnj")
    public suspend fun dnsServers(`value`: Output<List<String>>) {
        this.dnsServers = value
    }

    @JvmName("hboobivjhyqkmdub")
    public suspend fun dnsServers(vararg values: Output<String>) {
        this.dnsServers = Output.all(values.asList())
    }

    /**
     * @param values IPv4 address of the DNS servers in your environment.
     */
    @JvmName("velkjoahohadilpm")
    public suspend fun dnsServers(values: List<Output<String>>) {
        this.dnsServers = Output.all(values)
    }

    /**
     * @param value Default gateway that should be used for the provided IP address space.
     */
    @JvmName("mqqoxgkqwrydqnov")
    public suspend fun gateway(`value`: Output<String>) {
        this.gateway = value
    }

    /**
     * @param value Range of IP addresses from which addresses are allocated for nodes within a subnet.
     */
    @JvmName("olueuonrvowepjjq")
    public suspend fun ipPools(`value`: Output<List<IpPoolsArgs>>) {
        this.ipPools = value
    }

    @JvmName("jtgipsechxojovmc")
    public suspend fun ipPools(vararg values: Output<IpPoolsArgs>) {
        this.ipPools = Output.all(values.asList())
    }

    /**
     * @param values Range of IP addresses from which addresses are allocated for nodes within a subnet.
     */
    @JvmName("bxsynmlicdehqxaa")
    public suspend fun ipPools(values: List<Output<IpPoolsArgs>>) {
        this.ipPools = Output.all(values)
    }

    /**
     * @param value Subnet mask that matches the provided IP address space.
     */
    @JvmName("nyktxprddchqvxvp")
    public suspend fun subnetMask(`value`: Output<String>) {
        this.subnetMask = value
    }

    /**
     * @param value Allows customers to use DHCP for Hosts and Cluster IPs. If not declared, the deployment will default to static IPs. When true, GW and DNS servers are not required
     */
    @JvmName("ywtxlgqacqsrhwpr")
    public suspend fun useDhcp(`value`: Output<Boolean>) {
        this.useDhcp = value
    }

    /**
     * @param value IPv4 address of the DNS servers in your environment.
     */
    @JvmName("gxwrqsqvomdqtenh")
    public suspend fun dnsServers(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dnsServers = mapped
    }

    /**
     * @param values IPv4 address of the DNS servers in your environment.
     */
    @JvmName("ncrpjsnsrpmyifbp")
    public suspend fun dnsServers(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.dnsServers = mapped
    }

    /**
     * @param value Default gateway that should be used for the provided IP address space.
     */
    @JvmName("abhoebywqdgnvrem")
    public suspend fun gateway(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.gateway = mapped
    }

    /**
     * @param value Range of IP addresses from which addresses are allocated for nodes within a subnet.
     */
    @JvmName("bmqeuwrcebgoxjor")
    public suspend fun ipPools(`value`: List<IpPoolsArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.ipPools = mapped
    }

    /**
     * @param argument Range of IP addresses from which addresses are allocated for nodes within a subnet.
     */
    @JvmName("kmkqlsinplkxlwki")
    public suspend fun ipPools(argument: List<suspend IpPoolsArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map { IpPoolsArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.ipPools = mapped
    }

    /**
     * @param argument Range of IP addresses from which addresses are allocated for nodes within a subnet.
     */
    @JvmName("wglbublqrqgtqsmo")
    public suspend fun ipPools(vararg argument: suspend IpPoolsArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map { IpPoolsArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.ipPools = mapped
    }

    /**
     * @param argument Range of IP addresses from which addresses are allocated for nodes within a subnet.
     */
    @JvmName("fhsoomamvwaauygp")
    public suspend fun ipPools(argument: suspend IpPoolsArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(IpPoolsArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.ipPools = mapped
    }

    /**
     * @param values Range of IP addresses from which addresses are allocated for nodes within a subnet.
     */
    @JvmName("kinyrqekvxyyeyjw")
    public suspend fun ipPools(vararg values: IpPoolsArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.ipPools = mapped
    }

    /**
     * @param value Subnet mask that matches the provided IP address space.
     */
    @JvmName("piyxijopuxsnvbxm")
    public suspend fun subnetMask(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.subnetMask = mapped
    }

    /**
     * @param value Allows customers to use DHCP for Hosts and Cluster IPs. If not declared, the deployment will default to static IPs. When true, GW and DNS servers are not required
     */
    @JvmName("heqfdxycgukesqhg")
    public suspend fun useDhcp(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.useDhcp = mapped
    }

    internal fun build(): InfrastructureNetworkArgs = InfrastructureNetworkArgs(
        dnsServers = dnsServers,
        gateway = gateway,
        ipPools = ipPools,
        subnetMask = subnetMask,
        useDhcp = useDhcp,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/azurestackhci/kotlin/inputs/InfrastructureNetworkArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.azurestackhci.kotlin.inputs

import com.pulumi.azurenative.azurestackhci.inputs.InfrastructureNetworkArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * The InfrastructureNetwork of a AzureStackHCI Cluster.
 * @property dnsServers IPv4 address of the DNS servers in your environment.
 * @property gateway Default gateway that should be used for the provided IP address space.
 * @property ipPools Range of IP addresses from which addresses are allocated for nodes within a subnet.
 * @property subnetMask Subnet mask that matches the provided IP address space.
 * @property useDhcp Allows customers to use DHCP for Hosts and Cluster IPs. If not declared, the deployment will default to static IPs. When true, GW and DNS servers are not required
 */
public data class InfrastructureNetworkArgs(
    public val dnsServers: Output<List<String>>? = null,
    public val gateway: Output<String>? = null,
    public val ipPools: Output<List<IpPoolsArgs>>? = null,
    public val subnetMask: Output<String>? = null,
    public val useDhcp: Output<Boolean>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.azurestackhci.inputs.InfrastructureNetworkArgs> {
    override fun toJava(): com.pulumi.azurenative.azurestackhci.inputs.InfrastructureNetworkArgs =
        com.pulumi.azurenative.azurestackhci.inputs.InfrastructureNetworkArgs.builder()
            .dnsServers(dnsServers?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .gateway(gateway?.applyValue({ args0 -> args0 }))
            .ipPools(
                ipPools?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .subnetMask(subnetMask?.applyValue({ args0 -> args0 }))
            .useDhcp(useDhcp?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [InfrastructureNetworkArgs].
 */
@PulumiTagMarker
public class InfrastructureNetworkArgsBuilder internal constructor() {
    private var dnsServers: Output<List<String>>? = null

    private var gateway: Output<String>? = null

    private var ipPools: Output<List<IpPoolsArgs>>? = null

    private var subnetMask: Output<String>? = null

    private var useDhcp: Output<Boolean>? = null

    /**
     * @param value IPv4 address of the DNS servers in your environment.
     */
    @JvmName("kiukaqhuysblgwts")
    public suspend fun dnsServers(`value`: Output<List<String>>) {
        this.dnsServers = value
    }

    @JvmName("bddrlytjoxeaddpa")
    public suspend fun dnsServers(vararg values: Output<String>) {
        this.dnsServers = Output.all(values.asList())
    }

    /**
     * @param values IPv4 address of the DNS servers in your environment.
     */
    @JvmName("xuyxntknvwbrgjfx")
    public suspend fun dnsServers(values: List<Output<String>>) {
        this.dnsServers = Output.all(values)
    }

    /**
     * @param value Default gateway that should be used for the provided IP address space.
     */
    @JvmName("gcrjvdtvljitwvbw")
    public suspend fun gateway(`value`: Output<String>) {
        this.gateway = value
    }

    /**
     * @param value Range of IP addresses from which addresses are allocated for nodes within a subnet.
     */
    @JvmName("orcawfxqwhftryhq")
    public suspend fun ipPools(`value`: Output<List<IpPoolsArgs>>) {
        this.ipPools = value
    }

    @JvmName("xhvlebfayperfmef")
    public suspend fun ipPools(vararg values: Output<IpPoolsArgs>) {
        this.ipPools = Output.all(values.asList())
    }

    /**
     * @param values Range of IP addresses from which addresses are allocated for nodes within a subnet.
     */
    @JvmName("audtlllrydyrqwqo")
    public suspend fun ipPools(values: List<Output<IpPoolsArgs>>) {
        this.ipPools = Output.all(values)
    }

    /**
     * @param value Subnet mask that matches the provided IP address space.
     */
    @JvmName("ffsxpeguqrljpkqy")
    public suspend fun subnetMask(`value`: Output<String>) {
        this.subnetMask = value
    }

    /**
     * @param value Allows customers to use DHCP for Hosts and Cluster IPs. If not declared, the deployment will default to static IPs. When true, GW and DNS servers are not required
     */
    @JvmName("rbugtjkahgyhxvaj")
    public suspend fun useDhcp(`value`: Output<Boolean>) {
        this.useDhcp = value
    }

    /**
     * @param value IPv4 address of the DNS servers in your environment.
     */
    @JvmName("ldabygwvpthljaro")
    public suspend fun dnsServers(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dnsServers = mapped
    }

    /**
     * @param values IPv4 address of the DNS servers in your environment.
     */
    @JvmName("giuxevqmbikvavxw")
    public suspend fun dnsServers(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.dnsServers = mapped
    }

    /**
     * @param value Default gateway that should be used for the provided IP address space.
     */
    @JvmName("edceqglylwlljejk")
    public suspend fun gateway(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.gateway = mapped
    }

    /**
     * @param value Range of IP addresses from which addresses are allocated for nodes within a subnet.
     */
    @JvmName("cqehfdiwdqgaysiw")
    public suspend fun ipPools(`value`: List<IpPoolsArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.ipPools = mapped
    }

    /**
     * @param argument Range of IP addresses from which addresses are allocated for nodes within a subnet.
     */
    @JvmName("xvrfjekkhbqihawc")
    public suspend fun ipPools(argument: List<suspend IpPoolsArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map { IpPoolsArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.ipPools = mapped
    }

    /**
     * @param argument Range of IP addresses from which addresses are allocated for nodes within a subnet.
     */
    @JvmName("llifccjypilsnhag")
    public suspend fun ipPools(vararg argument: suspend IpPoolsArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map { IpPoolsArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.ipPools = mapped
    }

    /**
     * @param argument Range of IP addresses from which addresses are allocated for nodes within a subnet.
     */
    @JvmName("rnluyvhaypdamxxo")
    public suspend fun ipPools(argument: suspend IpPoolsArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(IpPoolsArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.ipPools = mapped
    }

    /**
     * @param values Range of IP addresses from which addresses are allocated for nodes within a subnet.
     */
    @JvmName("esrvqqhdosfhvtsh")
    public suspend fun ipPools(vararg values: IpPoolsArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.ipPools = mapped
    }

    /**
     * @param value Subnet mask that matches the provided IP address space.
     */
    @JvmName("sfqacyujaddhjyqt")
    public suspend fun subnetMask(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.subnetMask = mapped
    }

    /**
     * @param value Allows customers to use DHCP for Hosts and Cluster IPs. If not declared, the deployment will default to static IPs. When true, GW and DNS servers are not required
     */
    @JvmName("nhshwagqlyllxhda")
    public suspend fun useDhcp(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.useDhcp = mapped
    }

    internal fun build(): InfrastructureNetworkArgs = InfrastructureNetworkArgs(
        dnsServers = dnsServers,
        gateway = gateway,
        ipPools = ipPools,
        subnetMask = subnetMask,
        useDhcp = useDhcp,
    )
}
